@@ -7,7 +7,7 @@
 
 static gchar * serverstats_format_time(unsigned long seconds);
 static void serverstats_browser_save_myself(void);
-
+static void serverstats_status_changed(MpdObj *mi, ChangedStatusType what, void *pointer);
 /* Allow gmpc to check the version the plugin is compiled against */
 int plugin_api_version = PLUGIN_API_VERSION;
 /**
@@ -15,19 +15,11 @@ int plugin_api_version = PLUGIN_API_VERSION;
  */
 gmpcPlBrowserPlugin serverstats_gbp = {
 	/** add */
-	serverstats_add,
+	.add = serverstats_add,
 	/** selected */
-	serverstats_selected,
+	.selected = serverstats_selected,
 	/** unselected */
-	serverstats_unselected,
-	/** cat_selection_changed */
-	NULL,
-	/* */
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL
+	.unselected = serverstats_unselected,
 };
 
 
@@ -46,7 +38,8 @@ gmpcPlugin plugin = {
 	/** playlist extention struct */
 	.browser = &serverstats_gbp,
 	/** Connection changed */
-	.mpd_status_changed = serverstats_connection_changed,
+	.mpd_connection_changed = serverstats_connection_changed,
+    .mpd_status_changed = serverstats_status_changed,
 	/** enable/disable */
 	.get_enabled = serverstats_get_enabled,
 	.set_enabled = serverstats_set_enabled,
@@ -91,10 +84,11 @@ void serverstats_set_enabled(int enabled)
 	else
 	{
 		GtkTreePath *path = gtk_tree_row_reference_get_path(serverstats_ref);
+        GtkTreeModel *model = gtk_tree_row_reference_get_model(serverstats_ref);
 		if (path){
 			GtkTreeIter iter;
-			if (gtk_tree_model_get_iter(GTK_TREE_MODEL(playlist3_get_category_tree_store()), &iter, path)){
-				gtk_tree_store_remove(playlist3_get_category_tree_store(), &iter);
+			if (gtk_tree_model_get_iter(model, &iter, path)){
+				gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
 			}
 			gtk_tree_path_free(path);
 			gtk_tree_row_reference_free(serverstats_ref);
@@ -109,7 +103,7 @@ void serverstats_set_enabled(int enabled)
 static void serverstats_add(GtkWidget *category_tree)
 {
 	GtkTreePath *path;
-	GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(category_tree));
+	GtkTreeModel *model = GTK_TREE_MODEL(playlist3_get_category_tree_store()); 
 	GtkTreeIter iter;
     gint pos;
 	/**
@@ -121,8 +115,7 @@ static void serverstats_add(GtkWidget *category_tree)
 	 */
 	pos = cfg_get_single_value_as_int_with_default(config, "serverstats","position",2);
 	playlist3_insert_browser(&iter, pos);
-/*	gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);*/
-	gtk_tree_store_set(GTK_TREE_STORE(model), &iter, 
+	gtk_list_store_set(GTK_LIST_STORE(model), &iter, 
 			PL3_CAT_TYPE, plugin.id,
 			PL3_CAT_TITLE,"Server Statistics", 
 			PL3_CAT_INT_ID, "/",
@@ -141,7 +134,7 @@ static void serverstats_add(GtkWidget *category_tree)
 	 */
 	path = gtk_tree_model_get_path(GTK_TREE_MODEL(model), &iter);
 	if (path) {
-		serverstats_ref = gtk_tree_row_reference_new(GTK_TREE_MODEL(playlist3_get_category_tree_store()), path);
+		serverstats_ref = gtk_tree_row_reference_new(model, path);
 		gtk_tree_path_free(path);
 	}
 }
@@ -632,11 +625,19 @@ static gchar * serverstats_format_time(unsigned long seconds)
 
 void serverstats_plugin_init(void)
 {
+    gchar *path = gmpc_plugin_get_data_path(&plugin);
+    gchar *url = g_build_path(G_DIR_SEPARATOR_S,path, "serverstats", NULL);
+    debug_printf(DEBUG_WARNING,"Found url: %s\n", url);
+    /*
     gchar *path = NULL;
 
     path = g_strdup_printf("%s%c%s",plugin.path,G_DIR_SEPARATOR, "serverstats");
-    gtk_icon_theme_append_search_path(gtk_icon_theme_get_default (),path);
+    */
+
+    gtk_icon_theme_append_search_path(gtk_icon_theme_get_default (),url);
+
     g_free(path);	
+    g_free(url);
 }
 
 void serverstats_connection_changed(MpdObj *mi, int connect,void *usedata)
@@ -651,3 +652,10 @@ void serverstats_connection_changed(MpdObj *mi, int connect,void *usedata)
         gtk_combo_box_set_active(GTK_COMBO_BOX(serverstats_combo), -1);
     }
 }
+
+static void serverstats_status_changed(MpdObj *mi, ChangedStatusType what, void *pointer)
+{
+
+
+}
+
